
# Slot: subject




URI: [https://example.com/test65/child_of_named_thing_subject](https://example.com/test65/child_of_named_thing_subject)


## Domain and Range

[ChildOfNamedThing](ChildOfNamedThing.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ChildOfNamedThing](ChildOfNamedThing.md)
